@@ -9,7 +9,9 @@ from OFS.SimpleItem import SimpleItem
 class AreciboConfiguration(SimpleItem):
     implements(IAreciboConfiguration)
     account_number = FieldProperty(IAreciboConfiguration['account_number'])
+    app_name = FieldProperty(IAreciboConfiguration['app_name'])
     transport = FieldProperty(IAreciboConfiguration['transport'])
+    ignore_localhost = FieldProperty(IAreciboConfiguration['ignore_localhost'])
     
 def form_adapter(context):
     return getUtility(IAreciboConfiguration, name='Arecibo_config', context=context)
\ No newline at end of file
