@@ -10,10 +10,6 @@ from email.Utils import formatdate
 import smtplib
 import simplejson
 
-posturl = "http://www.areciboapp.com/v/1/"
-postaddress = "arecibo@clearwind.ca"
-url = urlparse(posturl)
-
 keys = ["account", "ip", "priority", "uid", 
     "type", "msg", "traceback", "user_agent", 
     "url", "status", "server", "timestamp",
@@ -26,7 +22,9 @@ class post:
         self._data = {}
         self.transport = "http"
         self.smtp_server = "localhost"
-        self.smtp_from = "noreply@clearwind.ca"
+        self.smtp_from = "noreply@thisshouldbeoverwritten.com"
+        self.smtp_to = "noone@thisshouldbeoverwritten.com"
+        self.posturl = "http://www.areciboapp.com/v/1/"
         self.set("server", gethostname())
         self.set("timestamp", formatdate())
         
@@ -45,6 +43,9 @@ class post:
         self._send()
 
     # private
+    def _get_url_parts(self):
+        return urlparse(self.posturl)
+    
     def _data_encoded(self):
         data = {}
         for k in keys:
@@ -61,17 +62,23 @@ class post:
             self._send_smtp()
     
     def _msg_body(self):
-        body = simplejson.dumps(self._data)
-        msg = "From: %s\r\nTo: %s\r\n\r\n%s" % (self.smtp_from, postaddress, body)
+        try:
+            body = simplejson.dumps(self._data)
+        except TypeError:
+            # the json dump can fail if message is a weird content type
+            self._data['msg'] = "%s"%self._data
+            body = simplejson.dumps(self._data)
+        msg = "From: %s\r\nTo: %s\r\n\r\n%s" % (self.smtp_from, self.smtp_to, body)
         return msg
             
     def _send_smtp(self):
         msg = self._msg_body()
         s = smtplib.SMTP(self.smtp_server)
-        s.sendmail(self.smtp_from, postaddress, msg)
+        s.sendmail(self.smtp_from, self.smtp_to, msg)
         s.quit()
     
     def _send_http(self):
+        url = self._get_url_parts()
         h = HTTPConnection(url[1])
         headers = {
             "Content-type": 'application/x-www-form-urlencoded; charset="utf-8"',
