@@ -1,10 +1,11 @@
 import sys
 import os 
-from lib.arecibo import post, postaddress
+from lib.arecibo import post
 from App.config import getConfiguration
 from AccessControl import getSecurityManager
 from ZODB.POSException import ConflictError
 from clearwind.arecibo.interfaces import IAreciboConfiguration
+from zope.app.component.hooks import getSite
 
 from logging import getLogger
 log = getLogger('Plone')
@@ -43,8 +44,12 @@ def get(context):
         return cfg
     if qu.account_number:
         cfg["account"] = qu.account_number
+    if qu.app_name:
+        cfg["app_name"] = qu.app_name
     if qu.transport == "smtp":
         cfg["transport"] = "smtp"
+    cfg["ignore_localhost"] = qu.ignore_localhost
+    
     return cfg
 
 def arecibo(context, **kw):
@@ -60,13 +65,26 @@ def arecibo(context, **kw):
     req = context.REQUEST
     error = post()
     
+    error.posturl = "http://%s.appspot.com/v/1/"%cfg["app_name"]
+    error.smtp_to = "django-%s@%s.appspotmail.com"%(cfg["account"], cfg["app_name"] )
+    error.smtp_from = getSite().portal_properties.email_from_address
+    
     mail_possible = not not context.MailHost.smtp_host
     if mail_possible and cfg["transport"] == "smtp":
         error.transport = "smtp"
-       
-    if kw.get("error_type") == 'NotFound':
+    
+    errorType = kw.get("error_type")
+    try:
+        ignoredExceptions = getSite().error_log._ignored_exceptions  
+        if errorType in ignoredExceptions:
+            log.debug('Error is in list of ignored exceptions, not forwarding to arecibo')
+            return
+    except: # don't want to kill error reporting if someone's config is amuck.
+        pass 
+        
+    if errorType == 'NotFound':
         status = 404
-    elif kw.get("error_type") == 'Unauthorized':
+    elif errorType == 'Unauthorized':
         status = 403
     else:
         status = 500
@@ -76,7 +94,7 @@ def arecibo(context, **kw):
     error.set("account", cfg["account"])
     error.set("priority", priority)
     error.set("user_agent", req.get('HTTP_USER_AGENT', ""))
-    
+        
     if req.get("QUERY_STRING"):
         error.set("url", "%s?%s" % (req['ACTUAL_URL'], req['QUERY_STRING']))
     else:
@@ -85,11 +103,17 @@ def arecibo(context, **kw):
     if kw.get("error_log_id"):
         error.set("uid", kw.get("error_log_id")) 
     
-    error.set("ip", req.get("X_FORWARDED_FOR", req.get('REMOTE_ADDR', '')))   
+    ip =  req.get("X_FORWARDED_FOR", req.get('REMOTE_ADDR', ''))
+    # don't forward errors from developer instances
+    if ip == "127.0.0.1" and cfg["ignore_localhost"]:
+        log.debug('Error is from localhost, not forwarding to arecibo')
+        return
+    
+    error.set("ip", ip)   
     error.set("type", kw.get("error_type"))
     error.set("status", status)
     error.set("request", "\n".join([ "%s: %s" % (k, req[k]) for k in headers if req.get(k)]))
-    
+
     if status != 404:
         # lets face it the 404 tb is not useful
         error.set("traceback", kw.get("error_tb"))
@@ -98,7 +122,7 @@ def arecibo(context, **kw):
     error.set("username", "%s (%s)" % (usr.getId(), usr.getUserName()))
     error.set("msg", kw.get("error_msg"))
 
-    if error.transport == "http":    
+    if error.transport == "http": 
         try:
             error.send()
         except ConflictError:
@@ -111,7 +135,7 @@ def arecibo(context, **kw):
         # use the MailHost to send out which is configured by the site
         # administrator, and has more functionality than straight smtplib
         try:
-            context.MailHost.send(error._msg_body())
+            context.MailHost.send(error._msg_body(), mto=error.smtp_to, mfrom=error.smtp_from)
         except ConflictError:
             raise
         except:
